@@ -36,10 +36,6 @@ def log_action(request, model, action, field_id ):
         ip_address=new_client_ip_address,
         is_private=is_routable,
         priv_address = client_ip,
-        latitude=lat,
-        longitude=lon,
-        country=country,
-        city=city,
         model=model,
         action=action,
         field_id=field_id,
